2024-07-26 Version: 1.5.0
- Support API DeleteInstanceLabels.
- Support API UpdateInstanceLabels.


2024-07-25 Version: 1.4.4
- Update API ListInstances: add param CreateUserId.


2024-07-09 Version: 1.4.3
- Update API CreateInstance: update param body.
- Update API GetInstance: update response param.
- Update API ListInstances: update response param.
- Update API UpdateInstance: update param body.


2024-07-08 Version: 1.4.2
- Update API CreateInstance: update param body.
- Update API GetInstance: update response param.
- Update API ListInstances: update response param.
- Update API UpdateInstance: update param body.


2024-06-24 Version: 1.4.1
- Update API CreateInstance: update param body.
- Update API GetInstance: update response param.
- Update API UpdateInstance: update param body.


2024-06-07 Version: 1.4.0
- Support API GetMetrics.


2024-06-04 Version: 1.3.1
- Update API ListInstances: add param Labels.
- Update API ListInstances: update response param.


2024-04-12 Version: 1.3.0
- Support API GetInstanceEvents.
- Update API GetInstance: update response param.


2024-02-22 Version: 1.2.0
- Support API GetInstanceEvents.


2024-01-09 Version: 1.1.45
- Generated python 2022-01-01 for pai-dsw.

2023-12-27 Version: 1.1.44
- Generated python 2022-01-01 for pai-dsw.

2023-08-21 Version: 1.1.43
- Generated python 2022-01-01 for pai-dsw.

2023-08-21 Version: 1.1.42
- Generated python 2022-01-01 for pai-dsw.

2023-03-28 Version: 1.1.41
- Support extended cidrs.

2023-01-29 Version: 1.1.40
- Support Resource Group Statistics.

2023-01-29 Version: 1.1.37
- Support Resource Group Statistics.

2023-01-29 Version: 1.1.36
- Support Resource Group Statistics.

2023-01-29 Version: 1.1.35
- Support instance snapshots information.

2023-01-17 Version: 1.1.34
- DSW instance id filter in list instance API.

2023-01-17 Version: 1.1.32
- Support instance id filter in list instance.

2022-12-13 Version: 1.1.31
- Support Instance Snapshot with Labels.

2022-11-17 Version: 1.1.30
- Support Lifecycle.

2022-11-16 Version: 1.1.29
- Support for updating instance.

2022-10-20 Version: 1.1.28
- DSW lifecycle sdk generate.

2022-10-11 Version: 1.1.26
- DSW lifecycle sdk generate.

2022-09-21 Version: 1.1.24
- Automatically generate sdk tasks.

2022-09-21 Version: 1.1.23
- Automatically generate sdk tasks.

2022-09-05 Version: 1.1.22
- DSW support role chain.

2022-08-30 Version: 1.1.20
- DSW support query instance metrics .

2022-08-08 Version: 1.1.19
- Release of list instance enhancement.

2022-07-15 Version: 1.1.18
- Release of list instance enhancement.

2022-05-18 Version: 1.1.17
- Release of list instance enhancement.

2022-03-28 Version: 1.1.12
- Release of list instance enhancement.

2022-03-07 Version: 0.0.2
- Release of list instance enhancement.

2022-01-20 Version: 0.0.1
- Release of init version.

